@@ -38,7 +38,7 @@ def rings(features_X, features_position, max_radio=[0.00014, 0.00024, 0.00034],
                 distances = distances/np.linalg.norm(distances)
             indexs = idxs[nearby_points]
             for f_index, feature in enumerate(features_X.columns):
-                subset_feature = features_X.iloc[indexs, :][feature].values/distances
+                subset_feature = features_X.iloc[indexs][feature]/distances
                 mean_feature = subset_feature.mean()
                 features_array[f_index].append(mean_feature) 
         
